
// import React from 'react';
// import axios from 'axios';
// import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
// import "./index.css";

// export const Sidenav = () => {
//     const [isSidebarCollapsed, setIsSidebarCollapsed] = React.useState(false);
//     const [Navs, setNavs] = React.useState([]);
//     const [user, setUser] = React.useState(null);

//     // Load user from localStorage
//     React.useEffect(() => {
//         const storedUser = JSON.parse(localStorage.getItem("user"));
//         if (storedUser) {
//             setUser(storedUser);
//         }
//     }, []);

//     // Fetch navigation items based on role ID
//     React.useEffect(() => {
//         const fetchNavs = async () => {
//             if (!user || !user.active_role_id) {
//                 console.log('User data or active_role_id is not available');
//                 return; // Don't make API call if user or role_id is missing
//             }

//             console.log('Fetching navs for role_id:', user.active_role_id);
            
//             try {
//                 const response = await axios.get(`http://localhost:8000/api/user/role-nav-items/${user.active_role_id}`);
//                 console.log('Navs Response:', response);

//                 if (response.data.success) {
//                     // Assuming `nav_id` in the response relates to the `Nav` model with `name` and `url`
//                     const navItems = response.data.data.map(navItem => {
//                         return {
//                             ...navItem,
//                             nav: navItem.nav || {} // Ensure that the `nav` object exists
//                         };
//                     });
//                     setNavs(navItems);
//                 } else {
//                     console.error('Failed to fetch navs:', response.data.message);
//                 }
//             } catch (error) {
//                 console.error('Error fetching navs:', error);
//             }
//         };

//         fetchNavs();
//     }, [user]);

//     // Toggle sidebar collapse state
//     const toggleSidebar = () => {
//         setIsSidebarCollapsed(!isSidebarCollapsed);
//     };

//     // Sort the nav items by position if needed
//     const storenavs = Navs.sort((a, b) => a.position - b.position);

//     return (
//         <>
//             <div className={`admin-content-sidebar ${isSidebarCollapsed ? "collapsed" : ""}`}>
//                 {/* Render navigation items */}
//                 {storenavs.length > 0 ? (
//                     storenavs.map((Nav, index) => (
//                         <div className="admin-content-sidebar-item" key={index}>
//                             {/* Access the correct properties for name and URL */}
//                             <a href={Nav.nav.url} className={!isSidebarCollapsed ? "show-text" : "hide-text"}>
//                                 {Nav.nav.name}
//                             </a>
//                         </div>
//                     ))
//                 ) : (
//                     <p>No navigation items found</p>
//                 )}
//             </div>
//         </>
//     );
// };


import React from 'react';
import axios from 'axios';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import "./index.css";

export const Sidenav = () => {
    const [isSidebarCollapsed, setIsSidebarCollapsed] = React.useState(false);
    const [Navs, setNavs] = React.useState([]);
    const [user, setUser] = React.useState(null);

    // Load user from localStorage
    React.useEffect(() => {
        const storedUser = JSON.parse(localStorage.getItem("user"));
        if (storedUser) {
            setUser(storedUser);
        }
    }, []);

    // Fetch navigation items based on role ID
    React.useEffect(() => {
        const fetchNavs = async () => {
            if (!user || !user.active_role_id) {
                console.log('User data or active_role_id is not available');
                return; // Don't make API call if user or role_id is missing
            }

            console.log('Fetching navs for role_id:', user.active_role_id);
            
            try {
                const response = await axios.get(`http://localhost:8000/api/user/role-nav-items/${user.active_role_id}`);
                console.log('Navs Response:', response);

                if (response.data.success) {
                    // Assuming `nav_id` in the response relates to the `Nav` model with `name` and `url`
                    const navItems = response.data.data.map(navItem => {
                        return {
                            ...navItem,
                            nav: navItem.nav || {} // Ensure that the `nav` object exists
                        };
                    });
                    setNavs(navItems);
                } else {
                    console.error('Failed to fetch navs:', response.data.message);
                }
            } catch (error) {
                console.error('Error fetching navs:', error);
            }
        };

        fetchNavs();
    }, [user]);

    // Toggle sidebar collapse state
    const toggleSidebar = () => {
        setIsSidebarCollapsed(!isSidebarCollapsed);
    };

    // Sort the nav items by position in a safe manner
    const sortedNavs = [...Navs].sort((a, b) => {
        return a.position - b.position;
    });

    return (
        <>
            <div className={`admin-content-sidebar ${isSidebarCollapsed ? "collapsed" : ""}`}>
                {/* Render navigation items */}
                {sortedNavs.length > 0 ? (
                    sortedNavs.map((Nav, index) => (
                        <div className="admin-content-sidebar-item" key={index}>
                            {/* Access the correct properties for name and URL */}
                            <a href={Nav.nav.url} className={!isSidebarCollapsed ? "show-text" : "hide-text"}>
                                {Nav.nav.name}
                            </a>
                        </div>
                    ))
                ) : (
                    <p>No navigation items found</p>
                )}
            </div>
        </>
    );
};
